:github_url: https://github.com/kumo-ai/kumo-sdk

Kumo SDK
========

`Kumo <https://kumo.ai/>`_ is an advanced machine learning (ML) platform that
leverages Graph Neural Networks (GNNs) to deliver predictive analytics and
insights directly from your relational data. Kumo simplifies the ML process by
eliminating the need for extensive data preparation, allowing you to focus on
generating valuable predictions and insights.

The Kumo Python SDK provides a composable, modular interface to train
best-in-class GNNs on your relational data warehouse, powered by the Kumo
machine learning platform.

If you haven't already `requested a demo <https://kumo.ai/contact>`_ or a
`free trial <https://kumo.ai/try/>`_, please do so to receive an API key.
If you already have an API key, get started with the :ref:`installation` and
:ref:`intro_by_example` below!

.. toctree::
   :maxdepth: 1
   :caption: Installation

   install/installation
   install/key_management
   install/spcs

.. toctree::
   :maxdepth: 1
   :caption: Getting Started

   get_started/introduction
   get_started/experimental_querying_rfm

.. toctree::
   :maxdepth: 1
   :caption: FAQ

   faq/table
   faq/graph
   faq/pquery
   faq/training

.. toctree::
   :maxdepth: 1
   :caption: Package Reference

   modules/root
   modules/connector
   modules/graph
   modules/pquery
   modules/encoder
   modules/trainer
   modules/utils
   modules/experimental
   modules/experimental_rfm
